##  Step 2: Define the Source System
Select which system serves as the source of truth for this mapping:
  * SAP LeanIX: Application data flows from SAP LeanIX to Jira Service Management
  * Jira Service Management: IT component data flows from Jira Service Management to SAP LeanIX


Choose Next after selecting the source system.
![Screenshot showing the source system selection step in the mapping wizard with options for SAP LeanIX and Jira Service Management.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio7eda3a7f6e98431ca7a032f411c4951f_LowRes.png)
Source System Selection
